@@ -54,7 +54,7 @@ class Writer:
         return await self.stub.RemoveResource(pb)  # type: ignore
 
     async def garbage_collector(self, shard_id: str):
-        await self.stub.GC(ShardId(id=shard_id))  # type: ignore
+        return await self.stub.GC(ShardId(id=shard_id))  # type: ignore
 
     @backoff.on_exception(backoff.expo, (AioRpcError,), max_tries=4)
     async def shards(self) -> ShardIds:
