@@ -42,6 +42,12 @@ pub mod env {
         fn generate_settings() -> NodeResult<Settings> {
             let mut builder = Settings::builder();
 
+            if let Ok(debug) = std::env::var("DEBUG") {
+                if debug == "true" {
+                    builder.with_debug();
+                }
+            }
+
             if let Ok(data_path) = std::env::var("DATA_PATH") {
                 builder.data_path(data_path);
             }
@@ -65,7 +71,7 @@ pub mod env {
             }
 
             if let Ok(Ok(true)) = std::env::var("DISABLE_SENTRY").map(|v| v.parse::<bool>()) {
-                builder.sentry_enabled = Some(false);
+                builder.without_sentry();
             }
 
             if let Ok(url) = std::env::var("SENTRY_URL") {
@@ -79,6 +85,10 @@ pub mod env {
             if let Ok(levels) = std::env::var("RUST_LOG") {
                 builder.log_levels(parse_log_levels(&levels));
             }
+            // support more standard LOG_LEVELS env var
+            if let Ok(levels) = std::env::var("LOG_LEVELS") {
+                builder.log_levels(parse_log_levels(&levels));
+            }
 
             if let Ok(Ok(true)) = std::env::var("JAEGER_ENABLED").map(|v| v.parse::<bool>()) {
                 builder.with_jaeger_enabled();
@@ -118,8 +128,19 @@ pub mod env {
                 builder.replication_delay_seconds(replication_delay_seconds);
             }
 
-            let settings = builder.build()?;
-            Ok(settings)
+            if let Ok(Ok(replication_max_concurrency)) =
+                std::env::var("REPLICATION_MAX_CONCURRENCY").map(|v| v.parse::<u64>())
+            {
+                builder.replication_max_concurrency(replication_max_concurrency);
+            }
+
+            if let Ok(Ok(replication_healthy_delay)) =
+                std::env::var("REPLICATION_HEALTHY_DELAY").map(|v| v.parse::<u64>())
+            {
+                builder.replication_healthy_delay(replication_healthy_delay);
+            }
+
+            builder.build()
         }
     }
 
@@ -134,26 +155,54 @@ pub mod env {
         #[test]
         #[serial]
         fn test_default_env_settings() {
+            // Safe current state of DATA_PATH
+            let data_path_copy = std::env::var("DATA_PATH");
+            // Remove DATA_PATH for the test
+            std::env::remove_var("DATA_PATH");
+
             let settings = EnvSettingsProvider::generate_settings().unwrap();
+
+            if let Ok(value) = data_path_copy {
+                // The state needs to be restored
+                std::env::set_var("DATA_PATH", value);
+            }
+
             assert_eq!(settings.shards_path().to_str().unwrap(), "data/shards")
         }
 
         #[test]
         #[serial]
         fn test_env_settings_data_path() {
+            // Safe current state of DATA_PATH
+            let data_path_copy = std::env::var("DATA_PATH");
+            // set DATA_PATH for the test
             std::env::set_var("DATA_PATH", "mydata");
+
             let settings = EnvSettingsProvider::generate_settings().unwrap();
+
+            match data_path_copy {
+                Ok(value) => std::env::set_var("DATA_PATH", value),
+                Err(_) => std::env::remove_var("DATA_PATH"),
+            }
+
             assert_eq!(settings.shards_path().to_str().unwrap(), "mydata/shards");
-            std::env::remove_var("DATA_PATH");
         }
 
         #[test]
         #[serial]
         fn test_disable_sentry() {
+            // Safe current state of DISABLE_SENTRY
+            let disable_sentry_copy = std::env::var("DISABLE_SENTRY");
+            // set DISABLE_SENTRY for the test
             std::env::set_var("DISABLE_SENTRY", "true");
+
             let settings = EnvSettingsProvider::generate_settings().unwrap();
-            assert!(!settings.sentry_enabled);
-            std::env::remove_var("DISABLE_SENTRY");
+            match disable_sentry_copy {
+                Ok(value) => std::env::set_var("DISABLE_SENTRY", value),
+                Err(_) => std::env::remove_var("DISABLE_SENTRY"),
+            }
+
+            assert!(!settings.sentry_enabled());
         }
     }
 }
