@@ -29,9 +29,9 @@ use std::collections::{HashMap, HashSet};
 use std::time::SystemTime;
 use std::{fs, io, path};
 
+use data_store::Interpreter;
 use disk_hnsw::DiskHnsw;
 use io::{BufWriter, Write};
-use key_value::Slot;
 use memmap2::Mmap;
 use node::Node;
 use nucliadb_core::tracing::{debug, error};
@@ -42,7 +42,7 @@ use ram_hnsw::RAMHnsw;
 use serde::{Deserialize, Serialize};
 pub use uuid::Uuid as DpId;
 
-use crate::data_types::{key_value, trie, trie_ram, vector, DeleteLog};
+use crate::data_types::{data_store, trie, trie_ram, vector, DeleteLog};
 use crate::formula::Formula;
 use crate::fst_index::{KeyIndex, Label, LabelIndex};
 use crate::VectorR;
@@ -236,7 +236,7 @@ impl<'a, Dlog: DeleteLog> Retriever<'a, Dlog> {
             nodes,
             delete_log,
             similarity,
-            no_nodes: key_value::get_no_elems(nodes),
+            no_nodes: data_store::stored_elements(nodes),
             min_score,
         }
     }
@@ -244,7 +244,7 @@ impl<'a, Dlog: DeleteLog> Retriever<'a, Dlog> {
         if x == self.no_nodes {
             self.temp
         } else {
-            key_value::get_value(Node, self.nodes, x)
+            data_store::get_value(Node, self.nodes, x)
         }
     }
 }
@@ -280,7 +280,7 @@ impl<'a, Dlog: DeleteLog> DataRetriever for Retriever<'a, Dlog> {
         if x == self.no_nodes {
             false
         } else {
-            let x = key_value::get_value(Node, self.nodes, x);
+            let x = data_store::get_value(Node, self.nodes, x);
             Node::has_label(x, label)
         }
     }
@@ -344,15 +344,7 @@ impl Elem {
     }
 }
 
-impl key_value::KVElem for Elem {
-    fn serialized_len(&self) -> usize {
-        Node::serialized_len(
-            &self.key,
-            &self.vector,
-            &self.labels.0,
-            self.metadata.as_ref(),
-        )
-    }
+impl data_store::IntoBuffer for Elem {
     fn serialize_into<W: io::Write>(self, w: W) -> io::Result<()> {
         Node::serialize_into(
             w,
@@ -400,7 +392,7 @@ impl Neighbour {
         }
     }
     fn new(Address(addr): Address, data: &[u8], score: f32) -> Neighbour {
-        let node = key_value::get_value(Node, data, addr);
+        let node = data_store::get_value(Node, data, addr);
         let (exact, _) = Node.read_exact(node);
         Neighbour {
             score,
@@ -441,10 +433,10 @@ impl AsRef<DataPoint> for DataPoint {
 
 impl DataPoint {
     pub fn stored_len(&self) -> Option<u64> {
-        if key_value::get_no_elems(&self.nodes) == 0 {
+        if data_store::stored_elements(&self.nodes) == 0 {
             return None;
         }
-        let node = key_value::get_value(Node, &self.nodes, 0);
+        let node = data_store::get_value(Node, &self.nodes, 0);
         Some(vector::vector_len(Node::vector(node)))
     }
     pub fn get_id(&self) -> DpId {
@@ -454,11 +446,18 @@ impl DataPoint {
         self.journal
     }
     pub fn get_keys<Dlog: DeleteLog>(&self, delete_log: &Dlog) -> Vec<String> {
-        key_value::get_keys(Node, &self.nodes)
-            .filter(|k| !delete_log.is_deleted(k))
-            .map(String::from_utf8_lossy)
-            .map(|s| s.to_string())
-            .collect()
+        let node_storage = &self.nodes;
+        let length = data_store::stored_elements(node_storage);
+        let data_iterator = (0..length).map(|i| data_store::get_value(Node, node_storage, i));
+        let mut keys = Vec::new();
+        for data in data_iterator {
+            if !delete_log.is_deleted(data) {
+                let raw_key = Node.get_key(data);
+                let string_key = String::from_utf8_lossy(raw_key).to_string();
+                keys.push(string_key);
+            }
+        }
+        keys
     }
 
     #[allow(clippy::too_many_arguments)]
@@ -481,7 +480,7 @@ impl DataPoint {
             min_score,
         );
 
-        let no_nodes = key_value::get_no_elems(&self.nodes);
+        let no_nodes = data_store::stored_elements(&self.nodes);
 
         let filter = FormulaFilter::new(
             filter,
@@ -536,17 +535,13 @@ impl DataPoint {
             .collect::<VectorR<Vec<_>>>()?;
 
         // Creating the node store
-        let node_producers = operants
+        let node_producers: Vec<_> = operants
             .iter()
-            .map(|dp| ((dp.0, Node), dp.1.nodes.as_ref()));
-        {
-            let mut node_buffer = BufWriter::new(&mut nodes);
-            key_value::merge(&mut node_buffer, node_producers.collect())?;
-            node_buffer.flush()?;
-        }
-
+            .map(|dp| ((dp.0, Node), dp.1.nodes.as_ref()))
+            .collect();
+        data_store::merge(&mut nodes, &node_producers)?;
         let nodes = unsafe { Mmap::map(&nodes)? };
-        let no_nodes = key_value::get_no_elems(&nodes);
+        let no_nodes = data_store::stored_elements(&nodes);
 
         // Creating the FSTs with the new nodes
         let (label_index, key_index) = if channel == Channel::EXPERIMENTAL {
@@ -655,7 +650,7 @@ impl DataPoint {
         root_dir: &path::Path,
         nodes: &[u8],
     ) -> VectorR<(Option<LabelIndex>, Option<KeyIndex>)> {
-        let no_nodes = key_value::get_no_elems(nodes);
+        let no_nodes = data_store::stored_elements(nodes);
 
         // building the KeyIndex and LabelIndex FSTs
         let fst_dir = root_dir.join(file_names::FST);
@@ -670,7 +665,7 @@ impl DataPoint {
 
         // we iterate on each node to fill `keys`
         for node_id in 0..no_nodes {
-            let node = key_value::get_value(Node, nodes, node_id);
+            let node = data_store::get_value(Node, nodes, node_id);
             let key: String = String::from_utf8(Node::key(node).to_vec())?;
             let node_labels = Node::labels(node);
 
@@ -707,7 +702,7 @@ impl DataPoint {
 
     pub fn new(
         dir: &path::Path,
-        mut elems: Vec<Elem>,
+        elems: Vec<Elem>,
         time: Option<SystemTime>,
         similarity: Similarity,
         channel: Channel,
@@ -731,17 +726,11 @@ impl DataPoint {
             .create(true)
             .open(id.join(file_names::HNSW))?;
 
-        elems.sort_by(|a, b| a.key.cmp(&b.key));
-        elems.dedup_by(|a, b| a.key.cmp(&b.key).is_eq());
-        {
-            // Serializing nodes on disk
-            // Nodes are stored on disk and mmaped.
-            let mut nodesf_buffer = BufWriter::new(&mut nodesf);
-            key_value::create_key_value(&mut nodesf_buffer, elems)?;
-            nodesf_buffer.flush()?;
-        }
+        // Serializing nodes on disk
+        // Nodes are stored on disk and mmaped.
+        data_store::create_key_value(&mut nodesf, elems)?;
         let nodes = unsafe { Mmap::map(&nodesf)? };
-        let no_nodes = key_value::get_no_elems(&nodes);
+        let no_nodes = data_store::stored_elements(&nodes);
 
         // Creating the FSTs
         let (label_index, key_index) = if channel == Channel::EXPERIMENTAL {
